@@ -447,7 +447,10 @@ class Update(MethodsInterface):
             if not git.checkUrl(url):
                 raise UpdateError(_("Git %s is unavailable") % url)
         # --------------DEPRECATED--------------#
-
+        # check for readonly fs
+        if not os.access(rpath, os.W_OK):
+            self.printWARNING(_("Read only FS was found in %s, skipping this step") % rpath)
+            return True
         chroot_path = path.normpath(self.clVars.Get('cl_chroot_path'))
         if chroot_path == '/':
             rpath_orig = rpath
